@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -67,16 +67,16 @@ FollowUpReminderSelectDateDialog::FollowUpReminderSelectDateDialog(QWidget *pare
     topLayout->addWidget(mainWidget);
     topLayout->addWidget(buttonBox);
     QVBoxLayout *mainLayout = new QVBoxLayout(mainWidget);
-    mainLayout->setMargin(0);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
     QFormLayout *formLayout = new QFormLayout;
-    formLayout->setMargin(0);
+    formLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->addLayout(formLayout);
 
     d->mDateComboBox = new KDateComboBox;
+    QDate currentDate = QDate::currentDate().addDays(1);
     d->mDateComboBox->setMinimumDate(QDate::currentDate());
     d->mDateComboBox->setObjectName(QStringLiteral("datecombobox"));
 
-    QDate currentDate = QDate::currentDate();
     d->mDateComboBox->setDate(currentDate);
 
     formLayout->addRow(i18n("Date:"), d->mDateComboBox);
@@ -125,7 +125,7 @@ Akonadi::Collection FollowUpReminderSelectDateDialog::collection() const
 void FollowUpReminderSelectDateDialog::accept()
 {
     const QDate date = selectedDate();
-    if (date <= QDate::currentDate()) {
+    if (date < QDate::currentDate()) {
         KMessageBox::error(this, i18n("The selected date must be greater than the current date."), i18n("Invalid date"));
         return;
     }
