@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -53,6 +53,10 @@ public:
 
     virtual void showConfigureDialog(QWidget *parent);
 
+    virtual QString extraScreenCss(const QString &headerFont) const;
+    virtual QString extraPrintCss(const QString &headerFont) const;
+    virtual QString extraCommonCss(const QString &headerFont) const;
+
 private:
     HeaderStylePluginPrivate *const d;
 };
