@@ -44,9 +44,6 @@
 #include <QFileDevice>
 
 namespace MimeTreeParser {
-QStringList replySubjPrefixes(QStringList() << QStringLiteral("Re\\s*:") << QStringLiteral("Re\\[\\d+\\]:") << QStringLiteral("Re\\d+:"));
-QStringList forwardSubjPrefixes(QStringList() << QStringLiteral("Fwd:") << QStringLiteral("FW:"));
-
 NodeHelper::NodeHelper()
     : mAttachmentFilesDir(new AttachmentTemporaryFilesDirs())
 {
@@ -209,6 +206,29 @@ void NodeHelper::setPartMetaData(KMime::Content *node, const PartMetaData &metaD
     mPartMetaDatas.insert(node, metaData);
 }
 
+QString NodeHelper::writeFileToTempFile(KMime::Content *node, const QString &filename)
+{
+    QString fname = createTempDir(persistentIndex(node));
+    if (fname.isEmpty()) {
+        return QString();
+    }
+    fname += QLatin1Char('/') + filename;
+    QFile f(fname);
+    if (!f.open(QIODevice::ReadWrite)) {
+        qCWarning(MIMETREEPARSER_LOG) << "Failed to write note to file:" << f.errorString();
+        mAttachmentFilesDir->addTempFile(fname);
+        return QString();
+    }
+    f.write(QByteArray());
+    mAttachmentFilesDir->addTempFile(fname);
+    // make file read-only so that nobody gets the impression that he might
+    // edit attached files (cf. bug #52813)
+    f.setPermissions(QFileDevice::ReadUser);
+    f.close();
+
+    return fname;
+}
+
 QString NodeHelper::writeNodeToTempFile(KMime::Content *node)
 {
     // If the message part is already written to a file, no point in doing it again.
@@ -244,6 +264,7 @@ QString NodeHelper::writeNodeToTempFile(KMime::Content *node)
     QFile f(fname);
     if (!f.open(QIODevice::ReadWrite)) {
         qCWarning(MIMETREEPARSER_LOG) << "Failed to write note to file:" << f.errorString();
+        mAttachmentFilesDir->addTempFile(fname);
         return QString();
     }
     f.write(data);
@@ -291,6 +312,7 @@ QString NodeHelper::createTempDir(const QString &param)
         // Not there or not writable
         if (!QDir().mkpath(fname)
             || !fFile.setPermissions(QFileDevice::WriteUser | QFileDevice::ReadUser | QFileDevice::ExeUser)) {
+            mAttachmentFilesDir->addTempDir(fname);
             return QString(); //failed create
         }
     }
@@ -310,7 +332,7 @@ void NodeHelper::forceCleanTempFiles()
 
 void NodeHelper::removeTempFiles()
 {
-    //Don't delete it it will delete in class
+    //Don't delete as it will be deleted in class
     mAttachmentFilesDir->removeTempFiles();
     mAttachmentFilesDir = new AttachmentTemporaryFilesDirs();
 }
@@ -468,7 +490,7 @@ KMMsgSignatureState NodeHelper::overallSignatureState(KMime::Content *node) cons
 
 void NodeHelper::magicSetType(KMime::Content *node, bool aAutoDecode)
 {
-    const QByteArray body = (aAutoDecode) ? node->decodedContent() : node->body();
+    const QByteArray body = aAutoDecode ? node->decodedContent() : node->body();
     QMimeDatabase db;
     QMimeType mime = db.mimeTypeForData(body);
 
@@ -476,55 +498,6 @@ void NodeHelper::magicSetType(KMime::Content *node, bool aAutoDecode)
     node->contentType()->setMimeType(mimetype.toLatin1());
 }
 
-// static
-QString NodeHelper::replacePrefixes(const QString &str, const QStringList &prefixRegExps, bool replace, const QString &newPrefix)
-{
-    bool recognized = false;
-    // construct a big regexp that
-    // 1. is anchored to the beginning of str (sans whitespace)
-    // 2. matches at least one of the part regexps in prefixRegExps
-    QString bigRegExp = QStringLiteral("^(?:\\s+|(?:%1))+\\s*")
-                        .arg(prefixRegExps.join(QStringLiteral(")|(?:")));
-    QRegExp rx(bigRegExp, Qt::CaseInsensitive);
-    if (!rx.isValid()) {
-        qCWarning(MIMETREEPARSER_LOG) << "bigRegExp = \""
-                                      << bigRegExp << "\"\n"
-                                      << "prefix regexp is invalid!";
-        // try good ole Re/Fwd:
-        recognized = str.startsWith(newPrefix);
-    } else { // valid rx
-        QString tmp = str;
-        if (rx.indexIn(tmp) == 0) {
-            recognized = true;
-            if (replace) {
-                return tmp.replace(0, rx.matchedLength(), newPrefix + QLatin1Char(' '));
-            }
-        }
-    }
-    if (!recognized) {
-        return newPrefix + QLatin1Char(' ') + str;
-    } else {
-        return str;
-    }
-}
-
-QString NodeHelper::cleanSubject(KMime::Message *message)
-{
-    return cleanSubject(message, replySubjPrefixes + forwardSubjPrefixes,
-                        true, QString()).trimmed();
-}
-
-QString NodeHelper::cleanSubject(KMime::Message *message, const QStringList &prefixRegExps, bool replace, const QString &newPrefix)
-{
-    QString cleanStr;
-    if (message) {
-        cleanStr
-            = NodeHelper::replacePrefixes(
-            message->subject()->asUnicodeString(), prefixRegExps, replace, newPrefix);
-    }
-    return cleanStr;
-}
-
 void NodeHelper::setOverrideCodec(KMime::Content *node, const QTextCodec *codec)
 {
     if (!node) {
@@ -742,7 +715,7 @@ KMime::Content *NodeHelper::fromHREF(const KMime::Message::Ptr &mMessage, const
         // index is the last part of the folder name: /
         const QRegExp rIndex(QStringLiteral("\\D\\.([e0-9.:]+)/"));
 
-        //search the occurence at most at the end
+        //search the occurrence at most at the end
         if (rIndex.lastIndexIn(path) != -1) {
             return contentFromIndex(mMessage.data(), rIndex.cap(1));
         }
@@ -756,7 +729,7 @@ QString NodeHelper::fixEncoding(const QString &encoding)
     // According to http://www.iana.org/assignments/character-sets, uppercase is
     // preferred in MIME headers
     const QString returnEncodingToUpper = returnEncoding.toUpper();
-    if (returnEncodingToUpper.contains(QStringLiteral("ISO "))) {
+    if (returnEncodingToUpper.contains(QLatin1String("ISO "))) {
         returnEncoding = returnEncodingToUpper;
         returnEncoding.replace(QLatin1String("ISO "), QStringLiteral("ISO-"));
     }
