@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,7 +31,7 @@ class WEBENGINEVIEWER_EXPORT WebHitTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit WebHitTest(QWebEnginePage *page, const QPoint &pos, QObject *parent = nullptr);
+    explicit WebHitTest(QWebEnginePage *page, const QPoint &zoomedPos, const QPoint &pos, QObject *parent = nullptr);
     ~WebHitTest();
 
 Q_SIGNALS:
